@@ -402,6 +402,10 @@ func main() {
 	pinNoPLAIN, _ := parseAuthPinFile(user)
 	noPLAIN := pinNoPLAIN || !*flagPLAINAllow
 
+	// Periodic server ping settings
+	psp := true
+	pspPeriod := 30000
+
 	// Set XMPP connection options.
 	options := xmpp.Options{
 		Host:        server,
@@ -430,8 +434,8 @@ func main() {
 		FastInvalidate:            *flagFastInvalidate,
 		NoPLAIN:                   noPLAIN,
 		NoSASLUpgrade:             *flagNoSASLUpgrade,
-		PeriodicServerPings:       true,
-		PeriodicServerPingsPeriod: 300000,
+		PeriodicServerPings:       psp,
+		PeriodicServerPingsPeriod: pspPeriod,
 	}
 	slog.Info("setting xmpp connection option:", "Host", server)
 	slog.Info("setting xmpp connection option:", "User", user)
@@ -451,6 +455,8 @@ func main() {
 	slog.Info("setting xmpp connection option:", "FastInvalidate", *flagFastInvalidate)
 	slog.Info("setting xmpp connection option:", "NoSASLUpgrade", *flagNoSASLUpgrade)
 	slog.Info("setting xmpp connection option:", "NoPLAIN", noPLAIN)
+	slog.Info("setting xmpp connection option:", "PeriodicServerPings", psp)
+	slog.Info("setting xmpp connection option:", "PeriodicServerPingsPeriod", pspPeriod)
 
 	// Read message from file.
 	if *flagMessageFile != "" {
