@@ -2,6 +2,7 @@
 // Use of this source code is governed by the BSD-2-clause
 // license that can be found in the LICENSE file.
 
+// TODO: Add logging
 package main
 
 import (
@@ -20,12 +21,12 @@ func findConfig() (string, error) {
 	// Get the current user.
 	curUser, err := user.Current()
 	if err != nil {
-		return "", fmt.Errorf("findConfig: failed to get current user: %w", err)
+		return "", fmt.Errorf("find config: failed to get current user: %w", err)
 	}
 	// Get home directory.
 	home := curUser.HomeDir
 	if home == "" {
-		return "", fmt.Errorf("findConfig: no home directory found")
+		return "", fmt.Errorf("find config: no home directory found")
 	}
 	osConfigDir := os.Getenv("$XDG_CONFIG_HOME")
 	if osConfigDir == "" {
@@ -33,8 +34,8 @@ func findConfig() (string, error) {
 	}
 	configFiles := [3]string{
 		osConfigDir + "/go-sendxmpp/config",
-		osConfigDir + "/go-sendxmpp/sendxmpprc", home +
-			"/.sendxmpprc",
+		osConfigDir + "/go-sendxmpp/sendxmpprc",
+		home + "/.sendxmpprc",
 	}
 
 	for _, r := range configFiles {
@@ -44,17 +45,12 @@ func findConfig() (string, error) {
 			return r, nil
 		}
 	}
-	return "", fmt.Errorf("findConfig: no configuration file found")
+	return "", fmt.Errorf("find config: no configuration file found")
 }
 
 // Opens the config file and returns the specified values
 // for username, server and port.
-func parseConfig(configPath string) (configuration, error) {
-	var (
-		output configuration
-		err    error
-	)
-
+func parseConfig(configPath string) (output configuration, err error) {
 	// Use $XDG_CONFIG_HOME/.config/go-sendxmpp/config,
 	// $XDG_CONFIG_HOME/.config/go-sendxmpp/sendxmpprc or
 	// ~/.sendxmpprc if no config path is specified.
@@ -76,14 +72,14 @@ func parseConfig(configPath string) (configuration, error) {
 		perm := info.Mode().Perm()
 		permissions := strconv.FormatInt(int64(perm), 8)
 		if permissions != "600" && permissions != "640" && permissions != "440" && permissions != "400" {
-			return output, fmt.Errorf("parseConfig: wrong permissions for %s: %s instead of 400 (recommended), 440, 600 or 640", configPath, permissions)
+			return output, fmt.Errorf("parse config: wrong permissions for %s: %s instead of 400 (recommended), 440, 600 or 640", configPath, permissions)
 		}
 	}
 
 	// Open config file.
 	file, err := os.Open(configPath)
 	if err != nil {
-		return output, fmt.Errorf("parseConfig: failed to open config file: %w", err)
+		return output, fmt.Errorf("parse config: failed to open config file: %w", err)
 	}
 	scanner := bufio.NewScanner(file)
 	scanner.Split(bufio.ScanLines)
@@ -152,7 +148,7 @@ func parseConfig(configPath string) (configuration, error) {
 		// Check if the username is a valid JID now
 		output.username, err = MarshalJID(output.username)
 		if err != nil {
-			return output, fmt.Errorf("parseConfig: invalid username/JID: %s", output.username)
+			return output, fmt.Errorf("parse config: invalid username/JID: %s", output.username)
 		}
 	}
 
